class PressureMine {
	constructor(game, x, y, r, direction){
		this.game = game;
		
		// Rendering
		this.texture = game.textures.projectiles;
		this.map = game.atlas.projectiles.pressureMine;
		
		// Scale
		this.scale = 1;
		this.width = 5;
		this.height = 5;
		
		// Physics
		this.x = x;
		this.y = y;
		this.r = r;
		this.vx = (Math.random() * 2 - 1) * 0.05;
		this.vy = (Math.random() * 2 - 1) * 0.05;
		this.vr = (Math.random() * 2 - 1) * 0.05;
		this.direction = direction;
		
		// Bolt
		this.maxLife = 5;
		this.life = this.maxLife;
		this.isAlive = true;
	}
	
	
	update(delta){
		// Physics
		this.x += this.vx * delta * 60;
		this.y += this.vy * delta * 60;
		this.r += this.vr * delta * 60;
		
		// Player Collision
		var player = this.game.scene.player,
			targetX = this.x,
			targetY = this.y;
		
		if(this.isAlive && this.height > Math.hypot(targetX - player.x, targetY - player.y)){
			player.damage(2);
			this.isAlive = false;
			this.life = 0;
			
			this.game.playTrack("explode");
			this.game.scene.addParticle(new Explosion(this.game, this.game.textures.projectiles, this.game.atlas.particles.explosion.green, this.x, this.y, this.r, this.vx, this.vy, this.vr))
			this.game.shake(0.4, 0.5);
		}
		
		// Create a particle
		if(this.game.canShowParticle(2)){
			// this.game.scene.addParticle(new PressureBoltTrail(this.game, this.texture, this.map, this.x, this.y, this.r, this.width, this.height, this.maxHeight, this.isAlive));
		}
		
		return this.life -= delta;
	}
	
	
	draw(context, textures, atlas){
		var texture = this.texture,
			map = this.map;
		
		context.save();
		context.translate(this.x, this.y);
		context.rotate(this.r/180*Math.PI);
		
		context.globalAlpha = this.life/this.maxLife > 0.5 ? (1 - this.life/this.maxLife) * 50 : this.life/this.maxLife * 50;
		
		context.drawImage(
			texture,
			
			// Sprite Crop Location
			map[0],
			map[1],
			map[2],
			map[3],
			
			// Screen Space Location
			-this.width/2,
			-this.height/2,
			this.width,
			this.height
		);

		context.restore();
	}
}
